@@ -1,6 +1,5 @@
 /*
- * Copyright (c) 2005-2011 Alon Bar-Lev <alon.barlev@gmail.com>
- * All rights reserved.
+ * Copyright (c) 2005-2018 Alon Bar-Lev <alon.barlev@gmail.com>
  *
  * This software is available to you under a choice of one of two
  * licenses.  You may choose to be licensed under the terms of the GNU
@@ -525,7 +524,7 @@ CK_RV
 pkcs11h_setForkMode (
 	IN const PKCS11H_BOOL safe
 ) {
-#if defined(ENABLE_PKCS11H_THREADING) && !defined(_WIN32)
+#if !defined(_WIN32)
 	_PKCS11H_ASSERT (_g_pkcs11h_data!=NULL);
 	_PKCS11H_ASSERT (_g_pkcs11h_data->initialized);
 
@@ -1010,7 +1009,9 @@ pkcs11h_forkFixup (void) {
 #if defined(ENABLE_PKCS11H_THREADING)
 	return CKR_OK;
 #else
-	return __pkcs11h_forkFixup (TRUE);
+	if (_g_pkcs11h_data->safefork) {
+		return __pkcs11h_forkFixup (TRUE);
+	}
 #endif
 #endif
 }
@@ -1279,10 +1280,6 @@ __pkcs11h_threading_atfork_child (void) {
 		if (_g_pkcs11h_data->safefork) {
 			__pkcs11h_forkFixup (TRUE);
 		}
-		else {
-			__pkcs11h_forkFixup (FALSE);
-			pkcs11h_terminate ();
-		}
 	}
 }
 
